/*
	*
	* Copyright 2019 Britanicus <marcusbritanicus@gmail.com>
	*
	* This file is a part of DesQ project (https://gitlab.com/desq/)
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* (at your option) any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#include "MimeUtils.hpp"

QMimeData *copyMimeData( QMimeData *original ) {

    QMimeData * mimeCopy = new QMimeData();

    for( QString format: original->formats() ) {

        // Retrieving data
        QByteArray data = original->data(format);

        // Checking for custom MIME types
        if ( format.startsWith( "application/x-qt" ) ) {
            // Retrieving true format name
            int indexBegin = format.indexOf( '"' ) + 1;
            int indexEnd = format.indexOf( '"', indexBegin );
            format = format.mid( indexBegin, indexEnd - indexBegin );
        }

        mimeCopy->setData( format, data );
    }

    return mimeCopy;
};

bool isDuplicate( QMimeData *first, QMimeData *second ) {

    /* If they're the same object */
    if ( first == second )
        return true;

    /*
        * If they don't have the same set of formats,
        * then they're probably different objects
    */
    if ( first->formats() != second->formats() )
        return false;

    /* Formats are same, check the contents */
    for( QString fmt: first->formats() ) {
        QByteArray firstData = first->data( fmt );
        QByteArray secondData = second->data( fmt );

        if ( firstData != secondData )
            return false;
    }

    /* Everything seems identical */
    return true;
};
